diff --git a/.claude-plugin/marketplace.json b/.claude-plugin/marketplace.json
index 109851ff0..9ab2695f8 100644
--- a/.claude-plugin/marketplace.json
+++ b/.claude-plugin/marketplace.json
@@ -11,7 +11,7 @@
"plugins": [
{
"name": "impeccable",
- "description": "Design vocabulary and skills for frontend development. Includes 17 commands (/polish, /simplify, /audit, /bolder, /quieter, etc.) and an enhanced frontend-design skill with curated anti-patterns.",
+ "description": "Design vocabulary and skills for frontend development. Includes 17 commands (/polish, /distill, /audit, /bolder, /quieter, etc.) and an enhanced frontend-design skill with curated anti-patterns.",
"version": "1.0.0",
"author": {
"name": "Paul Bakaus",
diff --git a/.claude-plugin/plugin.json b/.claude-plugin/plugin.json
index c46490fe9..23255deaf 100644
--- a/.claude-plugin/plugin.json
+++ b/.claude-plugin/plugin.json
@@ -1,6 +1,6 @@
{
"name": "impeccable",
- "description": "Design vocabulary and skills for frontend development. Includes 17 commands (/polish, /simplify, /audit, /bolder, /quieter, etc.) and an enhanced frontend-design skill with curated anti-patterns.",
+ "description": "Design vocabulary and skills for frontend development. Includes 17 commands (/polish, /distill, /audit, /bolder, /quieter, etc.) and an enhanced frontend-design skill with curated anti-patterns.",
"version": "1.0.0",
"author": {
"name": "Paul Bakaus",
diff --git a/.claude/commands/critique.md b/.claude/commands/critique.md
index e2901600e..7a3af3595 100644
--- a/.claude/commands/critique.md
+++ b/.claude/commands/critique.md
@@ -97,7 +97,7 @@ For each issue:
- **What**: Name the problem clearly
- **Why it matters**: How this hurts users or undermines goals
- **Fix**: What to do about it (be concrete)
-- **Command**: Which command to use (`/polish`, `/simplify`, `/bolder`, `/quieter`, etc.)
+- **Command**: Which command to use (`/polish`, `/distill`, `/bolder`, `/quieter`, etc.)
### Minor Observations
Quick notes on smaller issues worth addressing.
diff --git a/.claude/commands/simplify.md b/.claude/commands/distill.md
similarity index 98%
rename from .claude/commands/simplify.md
rename to .claude/commands/distill.md
index 8f0f1419e..4d6546d28 100644
--- a/.claude/commands/simplify.md
+++ b/.claude/commands/distill.md
@@ -1,9 +1,9 @@
---
-name: simplify
+name: distill
description: Strip designs to their essence by removing unnecessary complexity. Great design is simple, powerful, and clean.
args:
- name: target
- description: The feature or component to simplify (optional)
+ description: The feature or component to distill (optional)
required: false
---
diff --git a/README.md b/README.md
index 60db62e0e..52b374253 100644
--- a/README.md
+++ b/README.md
@@ -12,7 +12,7 @@ Every LLM learned from the same generic templates. Without guidance, you get the
Impeccable fights that bias with:
- **An expanded skill** with 7 domain-specific reference files ([view source](source/skills/frontend-design/))
-- **17 steering commands** to audit, review, polish, simplify, animate, and more
+- **17 steering commands** to audit, review, polish, distill, animate, and more
- **Curated anti-patterns** that explicitly tell the AI what NOT to do
## What's Included
@@ -40,7 +40,7 @@ A comprehensive design skill with 7 domain-specific references ([view skill](sou
| `/critique` | UX design review: hierarchy, clarity, emotional resonance |
| `/normalize` | Align with design system standards |
| `/polish` | Final pass before shipping |
-| `/simplify` | Strip to essence |
+| `/distill` | Strip to essence |
| `/clarify` | Improve unclear UX copy |
| `/optimize` | Performance improvements |
| `/harden` | Error handling, i18n, edge cases |
@@ -120,7 +120,7 @@ Once installed, use commands in your AI coding tool:
/audit # Find issues
/normalize # Fix inconsistencies
/polish # Final cleanup
-/simplify # Remove complexity
+/distill # Remove complexity
```
Most commands accept an optional argument to focus on a specific area:
diff --git a/public/cheatsheet.html b/public/cheatsheet.html
index 49ac0968d..352407dbd 100644
--- a/public/cheatsheet.html
+++ b/public/cheatsheet.html
@@ -195,7 +195,7 @@
'clarify': 'adaptation',
'quieter': 'intensity',
'bolder': 'intensity',
- 'simplify': 'adaptation',
+ 'distill': 'adaptation',
'animate': 'enhancement',
'colorize': 'enhancement',
'delight': 'enhancement',
@@ -207,7 +207,7 @@
const commandRelationships = {
'teach-impeccable': { flow: 'One-time project context gathering' },
'audit': { leadsTo: ['normalize', 'harden', 'optimize', 'adapt', 'clarify'], flow: 'Technical quality audit' },
- 'critique': { leadsTo: ['polish', 'simplify', 'bolder', 'quieter'], flow: 'UX and design review' },
+ 'critique': { leadsTo: ['polish', 'distill', 'bolder', 'quieter'], flow: 'UX and design review' },
'normalize': { combinesWith: ['clarify', 'adapt'], flow: 'Align with design system' },
'polish': { flow: 'Final pass before shipping' },
'optimize': { flow: 'Performance improvements' },
@@ -215,7 +215,7 @@
'clarify': { combinesWith: ['normalize', 'adapt'], flow: 'Improve UX copy' },
'quieter': { pairs: 'bolder', flow: 'Tone down bold designs' },
'bolder': { pairs: 'quieter', flow: 'Amplify timid designs' },
- 'simplify': { combinesWith: ['quieter', 'normalize'], flow: 'Strip to essence' },
+ 'distill': { combinesWith: ['quieter', 'normalize'], flow: 'Strip to essence' },
'animate': { combinesWith: ['delight'], flow: 'Add motion' },
'colorize': { combinesWith: ['bolder', 'delight'], flow: 'Add strategic color' },
'delight': { combinesWith: ['bolder', 'animate'], flow: 'Add personality' },
diff --git a/public/index.html b/public/index.html
index 4f8e4e3be..42812c5a2 100644
--- a/public/index.html
+++ b/public/index.html
@@ -54,7 +54,7 @@
Enhanced frontend-design skill + anti-patterns
·
- 17 commands: /polish, /audit, /simplify, /bolder...
+ 17 commands: /polish, /audit, /distill, /bolder...
diff --git a/public/js/data.js b/public/js/data.js
index 4af3c8593..7069f233c 100644
--- a/public/js/data.js
+++ b/public/js/data.js
@@ -47,7 +47,7 @@ export const commandProcessSteps = {
'clarify': ['Read', 'Simplify', 'Improve', 'Test'],
'quieter': ['Analyze', 'Reduce', 'Refine'],
'bolder': ['Analyze', 'Amplify', 'Impact'],
- 'simplify': ['Audit', 'Remove', 'Clarify'],
+ 'distill': ['Audit', 'Remove', 'Clarify'],
'animate': ['Identify', 'Design', 'Implement', 'Polish'],
'colorize': ['Analyze', 'Strategy', 'Apply', 'Balance'],
'delight': ['Identify', 'Design', 'Implement'],
@@ -67,7 +67,7 @@ export const commandCategories = {
'clarify': 'adaptation',
'quieter': 'intensity',
'bolder': 'intensity',
- 'simplify': 'adaptation',
+ 'distill': 'adaptation',
'animate': 'enhancement',
'colorize': 'enhancement',
'delight': 'enhancement',
@@ -88,7 +88,7 @@ export const skillRelationships = {
export const commandRelationships = {
'teach-impeccable': { flow: 'Setup: One-time project context gathering' },
'audit': { leadsTo: ['normalize', 'harden', 'optimize', 'adapt', 'clarify'], flow: 'Diagnostic: Technical quality audit' },
- 'critique': { leadsTo: ['polish', 'simplify', 'bolder', 'quieter'], flow: 'Diagnostic: UX and design review' },
+ 'critique': { leadsTo: ['polish', 'distill', 'bolder', 'quieter'], flow: 'Diagnostic: UX and design review' },
'normalize': { combinesWith: ['clarify', 'adapt'], flow: 'Quality: Align with design system' },
'polish': { flow: 'Quality: Final pass before shipping' },
'optimize': { flow: 'Quality: Performance improvements' },
@@ -96,7 +96,7 @@ export const commandRelationships = {
'clarify': { combinesWith: ['normalize', 'adapt'], flow: 'Adaptation: Improve UX copy' },
'quieter': { pairs: 'bolder', flow: 'Intensity: Tone down bold designs' },
'bolder': { pairs: 'quieter', flow: 'Intensity: Amplify timid designs' },
- 'simplify': { combinesWith: ['quieter', 'normalize'], flow: 'Adaptation: Strip to essence' },
+ 'distill': { combinesWith: ['quieter', 'normalize'], flow: 'Adaptation: Strip to essence' },
'animate': { combinesWith: ['delight'], flow: 'Enhancement: Add motion' },
'colorize': { combinesWith: ['bolder', 'delight'], flow: 'Enhancement: Add strategic color' },
'delight': { combinesWith: ['bolder', 'animate'], flow: 'Enhancement: Add personality' },
diff --git a/public/js/demos/commands/index.js b/public/js/demos/commands/index.js
index f42859b35..95c30f12a 100644
--- a/public/js/demos/commands/index.js
+++ b/public/js/demos/commands/index.js
@@ -10,7 +10,7 @@ import optimize from "./optimize.js";
import harden from "./harden.js";
import clarify from "./clarify.js";
import quieter from "./quieter.js";
-import simplify from "./simplify.js";
+import distill from "./distill.js";
import colorize from "./colorize.js";
import delight from "./delight.js";
import extract from "./extract.js";
@@ -28,7 +28,7 @@ export const commandDemos = {
harden,
clarify,
quieter,
- simplify,
+ distill,
colorize,
delight,
extract,
diff --git a/source/commands/critique.md b/source/commands/critique.md
index ebd49ac34..aa4611df2 100644
--- a/source/commands/critique.md
+++ b/source/commands/critique.md
@@ -97,7 +97,7 @@ For each issue:
- **What**: Name the problem clearly
- **Why it matters**: How this hurts users or undermines goals
- **Fix**: What to do about it (be concrete)
-- **Command**: Which command to use (`/polish`, `/simplify`, `/bolder`, `/quieter`, etc.)
+- **Command**: Which command to use (`/polish`, `/distill`, `/bolder`, `/quieter`, etc.)
### Minor Observations
Quick notes on smaller issues worth addressing.
diff --git a/dist/claude-code/.claude/commands/simplify.md b/source/commands/distill.md
similarity index 93%
rename from dist/claude-code/.claude/commands/simplify.md
rename to source/commands/distill.md
index 8f0f1419e..1607f94e3 100644
--- a/dist/claude-code/.claude/commands/simplify.md
+++ b/source/commands/distill.md
@@ -1,9 +1,9 @@
---
-name: simplify
+name: distill
description: Strip designs to their essence by removing unnecessary complexity. Great design is simple, powerful, and clean.
args:
- name: target
- description: The feature or component to simplify (optional)
+ description: The feature or component to distill (optional)
required: false
---
@@ -17,8 +17,8 @@ You cannot do a great job without having necessary context, such as target audie
Attempt to gather these from the current thread or codebase.
-1. If you don't find *exact* information and have to infer from existing design and functionality, you MUST STOP and STOP and call the AskUserQuestionTool to clarify. whether you got it right.
-2. Otherwise, if you can't fully infer or your level of confidence is medium or lower, you MUST STOP and call the AskUserQuestionTool to clarify. clarifying questions first to complete your context.
+1. If you don't find *exact* information and have to infer from existing design and functionality, you MUST STOP and {{ask_instruction}} whether you got it right.
+2. Otherwise, if you can't fully infer or your level of confidence is medium or lower, you MUST {{ask_instruction}} clarifying questions first to complete your context.
Do NOT proceed until you have answers. Simplifying the wrong things destroys usability.
@@ -46,7 +46,7 @@ Analyze what makes the design feel complex or cluttered:
- What can be removed, hidden, or combined?
- What's the 20% that delivers 80% of value?
-If any of these are unclear from the codebase, STOP and call the AskUserQuestionTool to clarify.
+If any of these are unclear from the codebase, {{ask_instruction}}
**CRITICAL**: Simplicity is not about removing features - it's about removing obstacles between users and their goals. Every element should justify its existence.
@@ -133,4 +133,4 @@ If you removed features or options:
- Consider if they need alternative access points
- Note any user feedback to monitor
-Remember: You have great taste and judgment. Simplification is an act of confidence - knowing what to keep and courage to remove the rest. As Antoine de Saint-Exupéry said: "Perfection is achieved not when there is nothing more to add, but when there is nothing left to take away."
\ No newline at end of file
+Remember: You have great taste and judgment. Simplification is an act of confidence - knowing what to keep and courage to remove the rest. As Antoine de Saint-Exupéry said: "Perfection is achieved not when there is nothing more to add, but when there is nothing left to take away."
diff --git a/public/js/demos/commands/simplify.js b/public/js/demos/commands/distill.js
similarity index 97%
rename from public/js/demos/commands/simplify.js
rename to public/js/demos/commands/distill.js
index 27c026c16..f0e4159fc 100644
--- a/public/js/demos/commands/simplify.js
+++ b/public/js/demos/commands/distill.js
@@ -1,6 +1,6 @@
// Simplify command demo - shows cluttered UI becoming minimal
export default {
- id: 'simplify',
+ id: 'distill',
caption: 'Cluttered interface → Essential elements only',
before: `
@@ -1,6 +1,6 @@
-// Simplify command demo - shows cluttered UI becoming minimal
+// Distill command demo - shows cluttered UI becoming minimal
export default {